import React, { Component } from 'react';
import {findDOMNode} from 'react-dom';
import TagInput from 'recruit-tag-input';
import DropList from './dropList';
import CommonMount from '@beisen-cmps/common-mount';
import './index.scss';

export default class extends Component {
	constructor(props) {
		super(props);
		this.state = {
			children: props.children && props.children.length>0 ? props.children : []
			,defaultItems: props.defaultItems && props.defaultItems.length>0 ? props.defaultItems : []
		}
		this.CommonMount = new CommonMount({
			containerId: 'DropdownList_ul', // 容器ID
			follow: true, // 是否滚动跟随，默认true
			fixed: true // 定位：fixed，false时为absolute
		});

		this.onClose = this.onClose.bind(this);
		this.handleClick = this.handleClick.bind(this);
	}

	componentWillReceiveProps(nextProps) {
		if (nextProps.children !== this.props.children) {
			this.setState({children: nextProps.children});
		}
	}

	addItems(event, val) {
		const { single } = this.props;
		const item = {
			text: val.text[0]
			,value: val.value
		}
		if ( single || single==undefined ) {
			this.state.defaultItems = [item];
		} else {
			let defaultItems = [...this.state.defaultItems];
			defaultItems.push(item);
			this.state.defaultItems = defaultItems;
		}
		this.setState(this.state);
		this.props.onSureClick && this.props.onSureClick(event, this.state.defaultItems);
	}

	renderDom() {
		const self = this;
		const dropdownDate = {
			limitCount: 10,
			multiple: true,
			children: this.state.children,
			dropdownWidth:  this.tar.offsetWidth,
			hasSearch: false,
			itemClick: function(event, val) {
				self.CommonMount.unmountBox();
				self.addItems(event, val);
			}
		}
		const showAutoUl = <DropList {...dropdownDate} />
		this.CommonMount.renderDom(
			'mount-box-dropdownlist', // wrap's classname & id
			showAutoUl, // content dom
			this.tar, // 跟随目标
			[
				this.tar, //挂载目标节点
				{ // 挂载元素宽高 {width: '', height: ''}
					width:  this.tar.clientWidth,// 挂载宽度
					height: 260
				}
			],
			true, //labeL和input框是否为竖向结构，会留出对应的label空间
      		0, //水平向左偏移量，为负数则向右
			false, //弹层靠左靠右模式，默认为false 靠左模式
			100, //window.onresize执行时间，默认100ms
			false,  //输入框高度
			false   //自定义zindex
		);
	}

	onClose(event) {
		try {
			findDOMNode(this);
		} catch(e) {
			this.CommonMount.unmountBox();
			document.removeEventListener('mousedown', this.onClose);
			this.props.onClose && this.props.onClose("close");
			return;
		}

		let area = document.getElementById("DropdownList_ul");
		if (area && !area.contains(event.target)) {
			// if (event.target.className.indexOf('sys-icon-close')>-1|| event.target.className.indexOf('u-icon')>-1 || event.target.tagName === 'BODY') return;
			this.CommonMount.unmountBox();
			document.removeEventListener('mousedown', this.onClose);
			this.props.onClose && this.props.onClose("close");
		}
	}

	handleClick(event, value) {
		this.tar = event.target.parentNode;
		this.renderDom();
		document.removeEventListener('mousedown', this.onClose);
  		document.addEventListener('mousedown', this.onClose);
	}

	render() {
		const self = this;
		const { maxCount, onSearch, title, isRequired, lablePos, lableTxt, errorStatus, errorMessage  } = this.props;
		let option = {
			maxCount: 5
			,defaultItems: this.state.defaultItems
			,title: title //label文本
			,isRequired: isRequired
			,lablePos: lablePos //label位置，true时在左边，false在上边
            ,lableTxt: lableTxt //label中文字对齐方式，true左对齐，false右对齐 
			,errorStatus: errorStatus
			,errorMessage: errorMessage
			,onClick: function(event, status, value) {
				self.handleClick(event, value)
			}
			,onFocus: function(event, status, value) {}
			,onChange: function(event, status, value) {
				onSearch(event, value)
			}
			,onBlur: function(event, status, value) {}
			,addItemCallBack: function(event, status, value) {}
			,deleteItemCallBack: function(event, status, value) {}
		}
    	return (
    		<div>
    			<TagInput {...option} />
    		</div>
  		)
  	}
}
